@@ -12,6 +12,7 @@
 #include <QPainter>
 #include <QPrintDialog>
 #include <QPrinter>
+#include <numeric>
 
 #include <KLocalizedString>
 
@@ -23,7 +24,7 @@
 #include "cttask.h"
 #include "ctvariable.h"
 
-#include "logging.h"
+#include "kcm_cron_debug.h"
 
 CrontabPrinter::CrontabPrinter(CrontabWidget *crontabWidget)
     : mCrontabWidget(crontabWidget)
@@ -41,7 +42,7 @@ CrontabPrinter::~CrontabPrinter()
 
 bool CrontabPrinter::start()
 {
-    logDebug() << "Printing selection...";
+    qCDebug(KCM_CRON_LOG) << "Printing selection...";
 
     if (!mPrinter) {
         mPrinter = new QPrinter();
@@ -57,10 +58,9 @@ bool CrontabPrinter::start()
 
     // initialize the printer using the print dialog
     auto printDialog = new QPrintDialog(mPrinter, nullptr);
-    printDialog->setOptionTabs(QList<QWidget *>() << mCrontabWidget);
     printDialog->setEnabledOptions(QAbstractPrintDialog::PrintToFile);
     if (printDialog->exec() == QDialog::Rejected) {
-        logDebug() << "Printing canceled";
+        qCDebug(KCM_CRON_LOG) << "Printing canceled";
         delete printDialog;
         return false;
     }
@@ -108,7 +108,7 @@ void CrontabPrinter::printTasks()
     taskHeaders << i18n("Scheduling") << i18n("Command") << i18n("Description");
     drawHeader(tasksColumnWidths, taskHeaders);
 
-    for (const QStringList &contents : qAsConst(tasksContent)) {
+    for (const QStringList &contents : std::as_const(tasksContent)) {
         drawContentRow(tasksColumnWidths, contents);
 
         needNewPage();
@@ -227,7 +227,7 @@ void CrontabPrinter::finish()
 
 void CrontabPrinter::printPageNumber()
 {
-    logDebug() << "Printing page number...";
+    qCDebug(KCM_CRON_LOG) << "Printing page number...";
 
     mPainter->translate(0, -mCurrentRowPosition);
     mPrintView->moveTo(QPoint(0, mPrintView->height()));
@@ -280,10 +280,7 @@ void CrontabPrinter::drawTable(const QList<int> &columnWidths)
 {
     mPainter->translate(0, -mCurrentRowPosition + computeMargin());
 
-    int columnWidthsTotal = 0;
-    for (int columnWidth : columnWidths) {
-        columnWidthsTotal += columnWidth;
-    }
+    int columnWidthsTotal = std::accumulate(columnWidths.begin(), columnWidths.end(), 0);
 
     const int margin = computeMargin();
     int linePositionX = margin;
@@ -349,13 +346,13 @@ QList<int> CrontabPrinter::findColumnWidths(const QList<QStringList> &contents,
     int pageWidth = mPainter->device()->width() - 2 * margin;
 
     int columnWidthSum = 0;
-    for (int width : qAsConst(columnWidths)) {
-        logDebug() << "Column : " << width;
+    for (int width : std::as_const(columnWidths)) {
+        qCDebug(KCM_CRON_LOG) << "Column : " << width;
         columnWidthSum += width;
     }
 
     if (columnWidthSum >= pageWidth) {
-        logDebug() << "The printing could be out of the page";
+        qCDebug(KCM_CRON_LOG) << "The printing could be out of the page";
         return columnWidths;
     }
 
