@@ -26,7 +26,6 @@
 #include <QAction>
 #include <QIcon>
 
-#include "ctGlobalCron.h"
 #include "ctcron.h"
 #include "cthost.h"
 #include "cttask.h"
@@ -38,33 +37,24 @@
 #include "variableWidget.h"
 
 #include "kcmCron.h"
-
-#include "logging.h"
-
-class CTGlobalCron;
+#include "kcm_cron_debug.h"
 
 CrontabWidget::CrontabWidget(QWidget *parent, CTHost *ctHost)
     : QWidget(parent)
 {
     mCtHost = ctHost;
 
-    if (mCtHost->isRootUser()) {
-        mCtGlobalCron = new CTGlobalCron(mCtHost);
-    } else {
-        mCtGlobalCron = nullptr;
-    }
-
     setupActions();
 
     initialize();
 
-    logDebug() << "Clipboard Status " << hasClipboardContent();
+    qCDebug(KCM_CRON_LOG) << "Clipboard Status " << hasClipboardContent();
 
     mTasksWidget->setFocus();
 
     QTreeWidgetItem *item = mTasksWidget->treeWidget()->topLevelItem(0);
     if (item != nullptr) {
-        logDebug() << "First item found" << mTasksWidget->treeWidget()->topLevelItemCount();
+        qCDebug(KCM_CRON_LOG) << "First item found" << mTasksWidget->treeWidget()->topLevelItemCount();
         item->setSelected(true);
     }
 
@@ -76,8 +66,6 @@ CrontabWidget::~CrontabWidget()
 {
     delete mTasksWidget;
     delete mVariablesWidget;
-
-    delete mCtGlobalCron;
 }
 
 bool CrontabWidget::hasClipboardContent()
@@ -110,40 +98,7 @@ QHBoxLayout *CrontabWidget::createCronSelector()
     group->addButton(mSystemCronRadio);
     layout->addWidget(mSystemCronRadio);
 
-    mOtherUserCronRadio = new QRadioButton(i18n("Cron of User:"), this);
-    group->addButton(mOtherUserCronRadio);
-
-    mOtherUsers = new QComboBox(this);
-
-    layout->addWidget(mOtherUserCronRadio);
-    layout->addWidget(mOtherUsers);
-
-    if (ctHost()->isRootUser()) {
-        QStringList users;
-
-        const auto crons = ctHost()->mCrons;
-        for (CTCron *ctCron : crons) {
-            if (ctCron->isCurrentUserCron()) {
-                continue;
-            }
-
-            if (ctCron->isSystemCron()) {
-                continue;
-            }
-
-            users.append(ctCron->userLogin());
-        }
-
-        users.sort();
-        mOtherUsers->addItems(users);
-        mOtherUsers->addItem(QIcon::fromTheme(QStringLiteral("users")), i18n("Show All Personal Crons"));
-    } else {
-        mOtherUserCronRadio->hide();
-        mOtherUsers->hide();
-    }
-
     connect(group, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), this, &CrontabWidget::refreshCron);
-    connect(mOtherUsers, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &CrontabWidget::checkOtherUsers);
 
     layout->addStretch(1);
 
@@ -154,9 +109,9 @@ void CrontabWidget::initialize()
 {
     auto layout = new QVBoxLayout(this);
 
-    logDebug() << "Begin view refresh";
+    qCDebug(KCM_CRON_LOG) << "Begin view refresh";
 
-    logDebug() << "Creating Tasks list...";
+    qCDebug(KCM_CRON_LOG) << "Creating Tasks list...";
 
     QHBoxLayout *cronSelector = createCronSelector();
     layout->addLayout(cronSelector);
@@ -178,30 +133,18 @@ void CrontabWidget::initialize()
 
 void CrontabWidget::refreshCron()
 {
+    // Refreshes the main GUI.
     CTCron *ctCron = currentCron();
 
     mTasksWidget->refreshTasks(ctCron);
     mVariablesWidget->refreshVariables(ctCron);
 
-    if (ctCron->isMultiUserCron() && !ctHost()->isRootUser()) {
-        logDebug() << "Disabling view...";
 
-        mTasksWidget->treeWidget()->setEnabled(false);
-        mVariablesWidget->treeWidget()->setEnabled(false);
+    mTasksWidget->treeWidget()->setEnabled(true);
+    mVariablesWidget->treeWidget()->setEnabled(true);
 
-        toggleNewEntryActions(false);
-        toggleModificationActions(false);
-        togglePasteAction(false);
-        mTasksWidget->toggleRunNowAction(false);
-    } else {
-        logDebug() << "Enabling view...";
-
-        mTasksWidget->treeWidget()->setEnabled(true);
-        mVariablesWidget->treeWidget()->setEnabled(true);
-
-        toggleNewEntryActions(true);
-        togglePasteAction(hasClipboardContent());
-    }
+    toggleNewEntryActions(true);
+    togglePasteAction(hasClipboardContent());
 }
 
 void CrontabWidget::copy()
@@ -215,7 +158,7 @@ void CrontabWidget::copy()
     QString clipboardText;
 
     if (mTasksWidget->treeWidget()->hasFocus()) {
-        logDebug() << "Tasks copying";
+        qCDebug(KCM_CRON_LOG) << "Tasks copying";
 
         const QList<TaskWidget *> tasksWidget = mTasksWidget->selectedTasksWidget();
         for (TaskWidget *taskWidget : tasksWidget) {
@@ -227,7 +170,7 @@ void CrontabWidget::copy()
     }
 
     if (mVariablesWidget->treeWidget()->hasFocus()) {
-        logDebug() << "Variables copying";
+        qCDebug(KCM_CRON_LOG) << "Variables copying";
 
         const QList<VariableWidget *> variablesWidget = mVariablesWidget->selectedVariablesWidget();
         for (VariableWidget *variableWidget : variablesWidget) {
@@ -241,39 +184,39 @@ void CrontabWidget::copy()
     QApplication::clipboard()->setText(clipboardText, QClipboard::Clipboard);
     QApplication::clipboard()->setText(clipboardText, QClipboard::Selection);
 
-    logDebug() << "Clipboard Status " << hasClipboardContent();
+    qCDebug(KCM_CRON_LOG) << "Clipboard Status " << hasClipboardContent();
     togglePasteAction(hasClipboardContent());
 }
 
 void CrontabWidget::cut()
 {
-    logDebug() << "Cut content";
+    qCDebug(KCM_CRON_LOG) << "Cut content";
 
     copy();
 
     if (mTasksWidget->treeWidget()->hasFocus()) {
-        logDebug() << "Tasks cutting";
+        qCDebug(KCM_CRON_LOG) << "Tasks cutting";
         mTasksWidget->deleteSelection();
     }
 
     if (mVariablesWidget->treeWidget()->hasFocus()) {
-        logDebug() << "Variables cutting";
+        qCDebug(KCM_CRON_LOG) << "Variables cutting";
         mVariablesWidget->deleteSelection();
     }
 }
 
 void CrontabWidget::paste()
 {
-    logDebug() << "Paste content";
+    qCDebug(KCM_CRON_LOG) << "Paste content";
 
     if (mTasksWidget->treeWidget()->hasFocus()) {
-        for (CTTask *task : qAsConst(mClipboardTasks)) {
+        for (CTTask *task : std::as_const(mClipboardTasks)) {
             mTasksWidget->addTask(new CTTask(*task));
         }
     }
 
     if (mVariablesWidget->treeWidget()->hasFocus()) {
-        for (CTVariable *variable : qAsConst(mClipboardVariables)) {
+        for (CTVariable *variable : std::as_const(mClipboardVariables)) {
             mVariablesWidget->addVariable(new CTVariable(*variable));
         }
     }
@@ -281,19 +224,13 @@ void CrontabWidget::paste()
 
 CTCron *CrontabWidget::currentCron() const
 {
+    // Checks which mode the gui is in, either user cron or system cron,
+    // returning the appropriate cron.
     if (mCurrentUserCronRadio->isChecked()) {
         return mCtHost->findCurrentUserCron();
-    } else if (mSystemCronRadio->isChecked()) {
+    } else {
         return mCtHost->findSystemCron();
     }
-
-    if (mOtherUsers->currentIndex() == mOtherUsers->count() - 1) {
-        logDebug() << "Using Global Cron";
-        return mCtGlobalCron;
-    }
-
-    QString currentUserLogin = mOtherUsers->currentText();
-    return mCtHost->findUserCron(currentUserLogin);
 }
 
 TasksWidget *CrontabWidget::tasksWidget() const
@@ -320,7 +257,7 @@ void CrontabWidget::checkOtherUsers()
 
 void CrontabWidget::setupActions()
 {
-    logDebug() << "Setup actions";
+    qCDebug(KCM_CRON_LOG) << "Setup actions";
 
     // Edit menu
     mCutAction = KStandardAction::cut(this, SLOT(cut()), this);
@@ -328,7 +265,7 @@ void CrontabWidget::setupActions()
     mPasteAction = KStandardAction::paste(this, SLOT(paste()), this);
     togglePasteAction(false);
 
-    logDebug() << "Actions initialized";
+    qCDebug(KCM_CRON_LOG) << "Actions initialized";
 }
 
 QList<QAction *> CrontabWidget::cutCopyPasteActions()
@@ -366,7 +303,7 @@ void CrontabWidget::print()
     CrontabPrinter printer(this);
 
     if (!printer.start()) {
-        logDebug() << "Unable to start printer";
+        qCDebug(KCM_CRON_LOG) << "Unable to start printer";
         return;
     }
     printer.printTasks();
