@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CRONTABWIDGET_H
-#define CRONTABWIDGET_H
+#pragma once
 
 #include <QWidget>
 
@@ -20,7 +19,6 @@ class CTHost;
 class CTCron;
 class QRadioButton;
 class QComboBox;
-class CTGlobalCron;
 
 /**
  * Main GUI view of the crontab entries.
@@ -140,10 +138,5 @@ private:
 
     QComboBox *mOtherUsers = nullptr;
 
-    /**
-     * Pointer to the pseudo Global Cron object
-     */
-    CTGlobalCron *mCtGlobalCron = nullptr;
 };
 
-#endif // CRONTABWIDGET_H
