@@ -20,19 +20,17 @@
 
 void KCronHelper::initUserCombo(QComboBox *userCombo, CrontabWidget *crontabWidget, const QString &selectedUserLogin)
 {
+    // This only applies to the System Crontab.
+    // Populate the "Run as:" combobox with the login names of all current crons,
+    // selecting the current user (root) as the default selection.
     int userComboIndex = 0;
 
     QStringList users;
     int selectedIndex = 0;
     const auto crons = crontabWidget->ctHost()->mCrons;
     for (CTCron *ctCron : crons) {
-        if (ctCron->isSystemCron()) {
-            continue;
-        }
-
         users.append(ctCron->userLogin());
 
-        // Select the actual user
         if (ctCron->userLogin() == selectedUserLogin) {
             selectedIndex = userComboIndex;
         }
@@ -48,7 +46,7 @@ void KCronHelper::initUserCombo(QComboBox *userCombo, CrontabWidget *crontabWidg
 
 QTextEdit *KCronHelper::createCommentEdit(QWidget *parent)
 {
-    QTextEdit *edit = new QTextEdit(parent);
+    auto edit = new QTextEdit(parent);
     edit->setAcceptRichText(false);
     edit->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
     edit->setTabChangesFocus(true);
