@@ -16,7 +16,7 @@
 #include "crontabWidget.h"
 #include "taskEditorDialog.h"
 
-#include "logging.h"
+#include "kcm_cron_debug.h"
 
 TaskWidget::TaskWidget(TasksWidget *_tasksWidget, CTTask *_cttask)
     : QTreeWidgetItem(_tasksWidget->treeWidget())
